@@ -97,6 +97,9 @@ kpxcSites.exceptionFound = function(identifier, field) {
         return true;
     } else if (document.location.origin === 'https://wordpress.com' && identifier?.value === 'login__form-password') {
         return true;
+    } else if (document.location.origin === 'https://id.atlassian.com' &&
+                Array.isArray(identifier) && identifier?.contains('password-field')) {
+        return true;
     }
 
     return false;
@@ -207,6 +210,10 @@ kpxcSites.formSubmitButtonExceptionFound = function(form) {
     } else if (!form && document.location.href.includes('reddit.com/settings')) {
         // Reddit change password popup
         return $('.button[slot=primary-button]');
+    } else if (form?.action === 'https://auth.openai.com/log-in/password') {
+        return form.querySelector('button[class*=_primary_]');
+    } else if (!form && document.location.origin === 'https://www.reddit.com') {
+        return $('button.login');
     }
 
     return undefined;
