@@ -2,6 +2,7 @@
 
 const DEFAULT_SEGMENTED_TOTP_FIELDS = 6;
 const MIN_SEGMENTED_TOTP_FIELDS = 4;
+const MAX_SEGMENTED_FIELD_LENGTH = 100;
 
 /**
  * @Object kpxcFields
@@ -46,7 +47,11 @@ kpxcFields.getAllCombinations = async function(inputs) {
         }
     }
 
-    if (kpxc.singleInputEnabledForPage && combinations.length === 0 && usernameField) {
+    // Allow single input if autocomplete="username" is present, or Username-Only Detection is enabled for the page
+    const autoComplete = usernameField?.getLowerCaseAttribute('autocomplete');
+    if (combinations.length === 0 && usernameField &&
+        (kpxc.singleInputEnabledForPage || autoComplete?.includes('username') || autoComplete?.includes('email'))
+    ) {
         const combination = {
             username: usernameField,
             password: null,
@@ -100,25 +105,27 @@ kpxcFields.getSegmentedTOTPFields = function(inputs, combinations) {
     // If ignoreFieldCount is true, number of TOTP fields are allowed to differ from the default (6),
     // but 4 at minimum must exist.
     const areFieldsSegmentedTotp = function(totpInputs, ignoreFieldCount = false) {
+        const fieldCountMatches = (ignoreFieldCount && totpInputs.length >= MIN_SEGMENTED_TOTP_FIELDS) ||
+            totpInputs.length === DEFAULT_SEGMENTED_TOTP_FIELDS;
+
+        const inputIsNumeric = (input) =>
+            (input.inputMode === 'numeric' || input.inputMode === '') && input.pattern.includes('0-9');
+
+        const inputIsText = (input) => input.offsetWidth < MAX_SEGMENTED_FIELD_LENGTH &&
+            (input.type === 'text' || input.type === 'number') && (input.maxLength === 1 || input.maxLength === -1);
+
         return (
-            ((ignoreFieldCount && totpInputs.length >= MIN_SEGMENTED_TOTP_FIELDS) ||
-                totpInputs.length === DEFAULT_SEGMENTED_TOTP_FIELDS) &&
-            totpInputs.every(
-                input =>
-                    ((input.inputMode === 'numeric' || input.inputMode === '') && input.pattern.includes('0-9')) ||
-                    ((input.type === 'text' || input.type === 'number') && (input.maxLength === 1 || input.maxLength === -1)) ||
-                    input.type === 'tel'
-            )
+            fieldCountMatches &&
+            totpInputs.every(input => inputIsNumeric(input) || inputIsText(input) || input.type === 'tel')
         );
     };
 
     const addTotpFieldsToCombination = function(inputFields, ignoreFieldCount = false) {
         const totpInputs = Array.from(inputFields).filter(
-            (e) =>
-                matchesWithNodeName(e, 'INPUT') &&
-                e.type !== 'password' &&
-                e.type !== 'hidden' &&
-                e.type !== 'submit'
+            (field) =>
+                matchesWithNodeName(field, 'INPUT') &&
+                [ 'hidden', 'password', 'submit' ].includes(field.type) === false &&
+                field.offsetWidth < MAX_SEGMENTED_FIELD_LENGTH
         );
 
         if (areFieldsSegmentedTotp(totpInputs, ignoreFieldCount)) {
@@ -404,8 +411,84 @@ kpxcFields.isSearchField = function(target) {
     return false;
 };
 
+// :popover-open selector is supported only with Firefox >= 125 and Chrome >= 114
+kpxcFields.discoverOverlays = function() {
+    try { 
+        kpxcFields.overlays = document.querySelectorAll(':popover-open, [popover]');
+    } catch (e) {
+        // Ignore SyntaxError (e.g., unsupported selector)
+        if (!(e instanceof SyntaxError)) {
+            logError(e);
+        }
+    }
+};
+
+// Checks if element has an overlay
+kpxcFields.hasOverlay = function(elem) {
+    try {
+        return elem?.hasAttribute('popover') || elem?.matches(':popover-open');
+    } catch (e) {
+        // Ignore SyntaxError (e.g., unsupported selector)
+        if (!(e instanceof SyntaxError)) {
+            logError(e);
+        }
+    }
+};
+
+// Check the visibility of existing fields
+kpxcFields.checkExistingFields = function() {
+    if (kpxc.inputs?.some(input => !kpxcFields.isVisible(input))) {
+        kpxc.clearAllFromPage();
+        kpxc.combinations = [];
+    }
+};
+
+kpxcFields.isTopElement = function(elem, rect) {
+    if (!elem || !rect) {
+        return false;
+    }
+
+    const rootNode = elem.getRootNode() ?? document;
+
+    // Returns the topmost element from point x, height/2
+    // If the input has a label as the top element and it's inside the input, allow it.
+    const getTopmostElement = (element, x, elementRect) => {
+        const topElement = rootNode.elementFromPoint(x, elementRect.top + (elementRect.height / 2));
+        return element?.labels &&
+            element.labels[0] === topElement &&
+            isElementInside(elementRect, topElement.getBoundingClientRect())
+            ? element
+            : topElement;
+    };
+
+    // Check topmost element from three points inside the input
+    if (matchesWithNodeName(elem, 'INPUT') && [
+        getTopmostElement(elem, rect.left + (rect.width / 4), rect), // First third
+        getTopmostElement(elem, rect.left + (rect.width / 2), rect), // Middle
+        getTopmostElement(elem, rect.left + (rect.width / 1.33), rect), // Last third
+    ].some((e) => e !== elem)) {
+        return false;
+    }
+
+    // Check for popup overlays
+    for (const overlay of kpxcFields.overlays ?? []) {
+        const overlayRect = overlay?.getBoundingClientRect();
+        if (overlayRect && elementsOverlap(rect, overlayRect)) {
+            return false;
+        }
+    }
+
+    return true;
+};
+
 // Returns true if element is visible on the page
 kpxcFields.isVisible = function(elem) {
+    // Returns true if opacity is not set, otherwise check the limits
+    const isOpacityAllowed = (opacity) => {
+        const opac = Number(opacity);
+        return opacity === '' || (opac >= MIN_OPACITY && opac <= MAX_OPACITY);
+    };
+
     // Check element position and size
     const rect = elem.getBoundingClientRect();
     if (rect.x < 0
@@ -417,18 +500,21 @@ kpxcFields.isVisible = function(elem) {
         return false;
     }
 
+    if (!kpxcFields.isTopElement(elem, rect)) {
+        return false;
+    }
+
     // Check CSS visibility
     const elemStyle = getComputedStyle(elem);
-    const opacity = Number(elemStyle.opacity);
     if (elemStyle.visibility && (elemStyle.visibility === 'hidden' || elemStyle.visibility === 'collapse')
-        || (opacity < MIN_OPACITY || opacity > MAX_OPACITY)
+        || !isOpacityAllowed(elemStyle.opacity)
         || parseInt(elemStyle.width, 10) <= MIN_INPUT_FIELD_WIDTH_PX
         || parseInt(elemStyle.height, 10) <= MIN_INPUT_FIELD_WIDTH_PX) {
         return false;
     }
 
     // Check for parent opacity
-    if (kpxcFields.traverseParents(elem, f => f.style.opacity === '0')) {
+    if (kpxcFields.traverseParents(elem, f => !isOpacityAllowed(f.style.opacity))) {
         return false;
     }
 
