@@ -10,7 +10,7 @@ kpxcForm.savedCustomInputs = [];
 kpxcForm.savedForms = [];
 kpxcForm.submitTriggered = false;
 
-// Activate the Credential Banner if existing credentials are not found
+// Activate the Credential Banner if credentials are found from form submit
 kpxcForm.activateCredentialBanner = async function(usernameValue, passwordInputs, passwordField) {
     let passwordValue = '';
     // Check if the form has three password fields -> a possible password change form
@@ -48,7 +48,12 @@ kpxcForm.formIdentified = function(form) {
 kpxcForm.getCredentialFieldsFromForm = function(form) {
     for (const savedForm of kpxcForm.savedForms) {
         if (savedForm.form === form) {
-            return [ savedForm.username, savedForm.password, savedForm.passwordInputs, savedForm.totp ];
+            // If savedForm has no values, query the form instead
+            return [
+                savedForm.username || form?.querySelector('input[type=text]'),
+                savedForm.password || form?.querySelector('input[type=password]'),
+                savedForm.passwordInputs,
+                savedForm.totp ];
         }
     }
 
@@ -158,9 +163,11 @@ kpxcForm.initForm = function(form, credentialFields) {
         form.addEventListener('submit', kpxcForm.onSubmit);
 
         const submitButton = kpxcForm.getFormSubmitButton(form);
-        if (submitButton !== undefined) {
+        if (submitButton) {
             submitButton.addEventListener('click', kpxcForm.onSubmit);
         }
+
+        kpxcUI.pageObserver.observe(form, OBSERVER_OPTIONS);
     }
 };
 
@@ -176,6 +183,15 @@ kpxcForm.initCustomForm = function(combinations) {
     }
 };
 
+// Identifies a submit button from the page outside any form
+kpxcForm.initSubmitButtonFromPage = function() {
+    let submitButton = kpxcSites.formSubmitButtonExceptionFound();    
+    submitButton ??= $('button[type=submit], button.login');
+    if (submitButton) {
+        submitButton.addEventListener('click', kpxcForm.onSubmit);
+    }
+};
+
 // Triggers when a custom form has been identified with a specific form submit button
 kpxcForm.onCustomFormSubmit = async function(e) {
     if (!e.isTrusted || kpxcForm.savedCustomInputs?.length === 0) {
@@ -222,14 +238,29 @@ kpxcForm.onSubmit = async function(e) {
         form = kpxcForm.savedForms[0].form;
     }
 
-    if (!form) {
+    // Try choosing inputs from the last combination detected.
+    // Needed if initSubmitButtonFromPage() has been used.
+    let usernameField;
+    let passwordField;
+    let passwordInputs = [];
+    if (!form && kpxc.combinations.length > 0) {
+        usernameField = kpxc.combinations.at(-1)?.username;
+        passwordField = kpxc.combinations.at(-1)?.password;
+        passwordInputs = kpxc.combinations.at(-1)?.passwordInputs;
+    } else {
+        [ usernameField, passwordField, passwordInputs ] = kpxcForm.getCredentialFieldsFromForm(form);
+    }
+
+    if (!form && !usernameField && !passwordField) {
         logDebug('Error: No form found for submit detection.');
         kpxcForm.submitTriggered = false;
         return;
     }
 
-    const [ usernameField, passwordField, passwordInputs ] = kpxcForm.getCredentialFieldsFromForm(form);
-    const usernameValue = await kpxcForm.getUsernameValue(usernameField);
+    // Use the first text field in the form if only username input is missing
+    const usernameValue = await kpxcForm.getUsernameValue(!usernameField && passwordField
+        ? form?.querySelector('input[type=text]')
+        : usernameField);
     await kpxcForm.activateCredentialBanner(usernameValue, passwordInputs, passwordField);
 };
 
