@@ -81,8 +81,9 @@ kpxc.clearAllFromPage = function() {
         kpxcUserAutocomplete.closeList();
     }
 
-    // Switch back to default popup
-    sendMessage('get_status', [ true ]); // This is an internal function call
+    // Clear logins from background and switch back to default popup
+    sendMessage('page_clear_logins');
+    sendMessage('get_status', [ true, false, true ]); // This is an internal function call, forceShowDefault
 };
 
 // Creates a new combination manually from active element
@@ -207,6 +208,8 @@ kpxc.getSite = function(sites) {
 kpxc.identifyFormInputs = async function() {
     const forms = [];
     const documentForms = document.forms; // Cache the value just in case
+    // Used for overlay security detection
+    kpxcFields.discoverOverlays();
 
     for (const form of documentForms) {
         if (!kpxcFields.isVisible(form)) {
@@ -321,9 +324,14 @@ kpxc.initCombinations = async function(inputs = []) {
     for (const c of combinations) {
         // If no username field is found, handle the single password field as such
         const field = c.username || c.password;
-        if (field && c.form) {
-            // Initialize form-submit for remembering credentials
-            kpxcForm.initForm(c.form, c);
+        if (field) {
+            if (c.form) {
+                // Initialize form-submit for remembering credentials
+                kpxcForm.initForm(c.form, c);
+            } else {
+                // Try to search a submit button
+                kpxcForm.initSubmitButtonFromPage();
+            }
         }
 
         // Don't allow duplicates
@@ -641,7 +649,7 @@ kpxc.rememberCredentialsFromContextMenu = async function() {
 // Credential Banner can force the retrieval for reloading new/modified credentials.
 kpxc.retrieveCredentials = async function(force = false) {
     if (!await isIframeAllowed()) {
-        return [];
+        return;
     }
 
     kpxc.url = document.location.href;
@@ -678,7 +686,7 @@ kpxc.retrieveCredentialsCallback = async function(credentials) {
 
 // If credentials are not received, request them again
 kpxc.receiveCredentialsIfNecessary = async function() {
-    if (kpxc.credentials.length === 0 && !_called.retrieveCredentials) {
+    if (kpxc.credentials.length === 0) {
         if (!await isIframeAllowed()) {
             return [];
         }
@@ -874,7 +882,7 @@ kpxc.usePredefinedSites = function(currentLocation) {
  * Content script initialization.
  */
 const initContentScript = async function() {
-    try {
+    try { 
         if (document?.documentElement?.ownerDocument?.contentType !== 'text/html'
             && document?.documentElement?.ownerDocument?.contentType !== 'application/xhtml+xml'
         ) {
@@ -981,6 +989,8 @@ browser.runtime.onMessage.addListener(async function(req, sender) {
             }
         } else if (req.action === 'ignore_site') {
             kpxc.ignoreSite(req.args);
+        } else if (req.action === 'is_site_ignored') {
+            return await kpxc.siteIgnored();
         } else if (req.action === 'redetect_fields') {
             const response = await sendMessage('load_settings');
             kpxc.settings = response;
@@ -996,7 +1006,10 @@ browser.runtime.onMessage.addListener(async function(req, sender) {
         } else if (req.action === 'show_password_generator') {
             kpxcPasswordGenerator.showPasswordGenerator();
         } else if (req.action === 'request_autotype') {
-            sendMessage('request_autotype', [ window.location.hostname ]);
+            // All frames can perform this. Ignore iframes that are not allowed.
+            if (await isIframeAllowed()) {
+                sendMessage('request_autotype', [ window.location.hostname ]);
+            }
         }
     }
 });
@@ -1018,6 +1031,13 @@ kpxc.reconnect = async function() {
 
 const isIframeAllowed = async function() {
     sendMessage('iframe_detected', false);
+
+    // Don't allow sandboxed iframes
+    if (self.origin === null || self.origin === 'null') {
+        logDebug('Error: Sandboxed iframes are not allowed');
+        return false;
+    }
+
     try {
         // Check for Cross-domain security error when inspecting window.top.location.href
         const currentLocation = window.top.location.href;
