@@ -13,6 +13,8 @@ const ORANGE_BUTTON = 'kpxc-button kpxc-orange-button';
 const RED_BUTTON = 'kpxc-button kpxc-red-button';
 const GRAY_BUTTON_CLASS = 'kpxc-gray-button';
 
+const OBSERVER_OPTIONS = { attributes: true, attributeFilter: [ 'style' ] };
+
 const DatabaseState = {
     DISCONNECTED: 0,
     LOCKED: 1,
@@ -69,6 +71,7 @@ class Icon {
         this.shadowRoot.append(styleSheet);
         this.shadowRoot.append(this.icon);
         document.body.append(wrapper);
+        kpxcUI.observeWrapper(wrapper);
     }
 
     switchIcon(state, uuid) {
@@ -394,6 +397,37 @@ kpxcUI.createButton = function(color, textContent, callback) {
     return button;
 };
 
+// Observe and prevent style changes to wrapper div elements
+kpxcUI.createWrapperObserver = function() {
+    kpxcUI.wrapperObserver = new MutationObserver(function(mutations, obs) {
+        for (const mut of mutations) {
+            if (mut?.target && mut.target.style?.cssText !== 'all: unset;') {
+                mut.target.removeAttribute('style');
+                mut.target.style.all = 'unset';
+            }
+        }
+    });
+};
+
+kpxcUI.observeWrapper = function(elem) {
+    kpxcUI.wrapperObserver?.observe(elem, OBSERVER_OPTIONS);
+};
+
+// Observer <html> and <body> style changes
+kpxcUI.createPageObserver = function() {
+    kpxcUI.pageObserver = new MutationObserver(function(mutations, obs) {
+        for (const mut of mutations) {
+            const currentStyle = getComputedStyle(mut?.target);
+            if (currentStyle.opacity && currentStyle.opacity < MIN_OPACITY) {
+                kpxc.clearAllFromPage();
+            }
+        }
+    });
+
+    kpxcUI.pageObserver.observe(document.documentElement, OBSERVER_OPTIONS);
+    kpxcUI.pageObserver.observe(document.body, OBSERVER_OPTIONS);
+};
+
 const DOMRectToArray = function(domRect) {
     return [ domRect.bottom, domRect.height, domRect.left, domRect.right, domRect.top, domRect.width, domRect.x, domRect.y ];
 };
@@ -423,6 +457,11 @@ const logDebug = function(message, extra) {
     }
 };
 
+const initObservers = function() {
+    kpxcUI.createWrapperObserver();
+    kpxcUI.createPageObserver();
+};
+
 document.addEventListener('mousedown', function(e) {
     if (!e.isTrusted) {
         return;
@@ -439,6 +478,12 @@ document.addEventListener('mouseup', function(e) {
     kpxcUI.mouseDown = false;
 });
 
+if (document.readyState === 'complete' || (document.readyState !== 'loading' && !document.documentElement.doScroll)) {
+    initObservers();
+} else {
+    document.addEventListener('DOMContentLoaded', initObservers);
+}
+
 HTMLDivElement.prototype.appendMultiple = function(...args) {
     for (const a of args) {
         this.append(a);
